@@ -28,7 +28,7 @@ logview_about (GtkWidget *widget, GtkWidget *window)
 {
   /* Author needs some sort of dash over the 'e' in Cesar  - U-00E9 */
   static const gchar *author[] = { "Cesar Miquel <miquel@df.uba.ar>",
-				   "Glynn Foster <fherrera@onirica.com>)",
+				   "Glynn Foster <fherrera@onirica.com>",
 				   "Fernando Herrera  <fherrera@onirica.com>",
 				   "Shakti Sen  <shprasad@novell.com>",
 				   "Julio M Merino Vidal <jmmv@menta.net>",
@@ -37,9 +37,12 @@ logview_about (GtkWidget *widget, GtkWidget *window)
 				   "Jan Arne Petersen  <jpetersen@uni-bonn.de>",
 				   "Jason Long  <jlong@messiah.edu>",
 				   "Kjartan Maraas  <kmaraas@gnome.org>",
-				   "Vincent Noel  <vnoel@cox.net>",
+				   "Vincent Noel  <vincent.noel@gmail.com>",
 				   NULL};
-  gchar *documenters[] = {NULL};
+  gchar *documenters[] = { "Sun GNOME Documentation Team <gdocteam@sun.com>",
+			   "Vincent Noel <vincent.noel@gmail.com>",
+			   "Judith Samson <judith@samsonsource.com>",
+			   NULL};
   /* Translator credits */
   const gchar *translator_credits = _("translator-credits");
   g_return_if_fail (GTK_IS_WINDOW (window));
